---
title: "Unanswered questions"
linkTitle: "Unanswered questions"
weight: 4
description: >
  Some peripherals have default values they are set to on reset. Should we include that information in the specification?
---